@@ -19,7 +19,7 @@ class WrongHashAlgorithm(Exception):
 
 class Auth(AuthenticationMixin, AuthorizationMixin, ViewsMixin):
 
-    defaults = {
+    default_settings = {
         'session_key': '_uhmac',
         'csrf_key': '_csrf_token',
         'csrf_header': 'X-CSRFToken',
@@ -73,12 +73,11 @@ class Auth(AuthenticationMixin, AuthorizationMixin, ViewsMixin):
     def __init__(self, secret_key, db=None, hash=DEFAULT_HASHER, rounds=None,
                  UserMixin=None, RoleMixin=None,
                  users_model_name='User', roles_model_name='Role',
-                 roles=False, lazy_roles=True,
-                 session=None, request=None, **kwargs):
+                 roles=False, lazy_roles=True, **settings):
 
         self.secret_key = str(secret_key)
         assert len(self.secret_key) >= MIN_SECRET_LENGTH, \
-            "`secret_key` must be at least {0} chars long".format(MIN_SECRET_LENGTH)
+            "`secret_key` must be at least {} chars long".format(MIN_SECRET_LENGTH)
         self.set_hasher(hash, rounds)
 
         self.db = db
@@ -95,13 +94,10 @@ class Auth(AuthenticationMixin, AuthorizationMixin, ViewsMixin):
             self.auth_password,
             self.auth_token,
         ]
+        self.session = {}
 
-        for key, val in self.defaults.items():
-            setattr(self, key, kwargs.get(key, self.defaults[key]))
-
-        # backwards compatibility
-        self.session = session or {}
-        self.request = request
+        for name in self.default_settings:
+            setattr(self, name, settings.get(name, self.default_settings[name]))
 
     def set_hasher(self, hash, rounds=None):
         """Updates the has algorithm and, optionally, the number of rounds
@@ -129,6 +125,5 @@ class Auth(AuthenticationMixin, AuthorizationMixin, ViewsMixin):
             hash + '__default_rounds': rounds
         }
         self.hasher = CryptContext(**op)
-        # For testing
-        self.hash = hash.replace('_', '-')
+        self.hash = hash.replace('_', '-')  # For testing
         self.rounds = rounds
